package dareka;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;

public class Main {
    private static final String VER_STRING = "NicoCache v0.09";

    /**
     * @param args
     * @throws IOException
     */
    public static void main(String[] args) throws IOException {
        File configFile = new File("config.properties");
        Config config = new Config();
        if (configFile.exists()) {
            Properties p = new Properties();

            FileInputStream in = new FileInputStream(configFile);
            try { // ensure closing in
                p.load(in);
            } finally {
                in.close();
            }

            config.listenPort = Integer.valueOf(p.getProperty("listenPort",
                    "8080"));
            config.proxyHost = p.getProperty("proxyHost", "");
            config.proxyPort = Integer.valueOf(p.getProperty("proxyPort",
                    "8081"));
            config.title = Boolean.valueOf(p.getProperty("title", "true"));
        } else {
            config.listenPort = 8080;
            config.proxyHost = "";
            config.proxyPort = 8081;
            config.title = true;

            Properties p = new Properties();
            p.setProperty("listenPort", Integer.toString(config.listenPort));
            p.setProperty("proxyHost", config.proxyHost);
            p.setProperty("proxyPort", Integer.toString(config.proxyPort));
            p.setProperty("title", Boolean.toString(config.title));

            FileOutputStream out = new FileOutputStream(configFile);
            try { // ensure closing out
                p.store(out, "NicoCache config file");
            } finally {
                out.close();
            }
        }

        System.out.println(VER_STRING);
        System.out.println("port=" + config.listenPort);
        if (config.proxyHost.equals("")) {
            System.out.println("direct mode (no secondary proxy)");
        } else {
            System.out.println("proxy host=" + config.proxyHost);
            System.out.println("proxy port=" + config.proxyPort);
        }
        System.out.println("title=" + config.title);

        Cache.init();
        Cache.cleanup();
        System.out.printf("total cache size=%,dbytes\n", Cache.size());

        Server s = new Server(config);

        try {
            s.start();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

}
